@@ -216,7 +216,6 @@ import           Data.Maybe                  (isNothing, isJust)
 import           Data.Monoid                 (Monoid (..))
 import           Data.MonoTraversable
 import qualified Data.Sequences              as Seq
-import           Data.Sequences.Lazy
 import qualified Data.Vector.Generic         as V
 import qualified Data.Vector.Generic.Mutable as VM
 import           Data.Void                   (absurd)
@@ -230,7 +229,6 @@ import Data.Word (Word8)
 import qualified Prelude
 import           System.IO                   (Handle)
 import qualified System.IO                   as SIO
-import qualified Data.Textual.Encoding as DTE
 import qualified Data.Conduit.Text as CT
 import Data.ByteString (ByteString)
 import Data.Text (Text)
@@ -241,6 +239,14 @@ import Data.Conduit.Internal.Fusion
 import           Data.Primitive.MutVar       (MutVar, newMutVar, readMutVar,
                                               writeMutVar)
 
+#if MIN_VERSION_mono_traversable(1,0,0)
+import qualified Data.Sequences as DTE
+import           Data.Sequences (LazySequence (..))
+#else
+import           Data.Sequences.Lazy
+import qualified Data.Textual.Encoding as DTE
+#endif
+
 -- Defines INLINE_RULE0, INLINE_RULE, STREAMING0, and STREAMING.
 #include "fusion-macros.h"
 
@@ -409,7 +415,7 @@ INLINE_RULE(replicateM, n m, CL.replicateM n m)
 -- including @ByteString@ and @Text@.
 --
 -- Since 1.0.0
-sourceFile :: (MonadResource m, IOData a) => FilePath -> Producer m a
+sourceFile :: (MonadResource m, IOData a, MonoFoldable a) => FilePath -> Producer m a
 sourceFile fp = sourceIOHandle (SIO.openFile fp SIO.ReadMode)
 {-# INLINE sourceFile #-}
 
@@ -420,7 +426,7 @@ sourceFile fp = sourceIOHandle (SIO.openFile fp SIO.ReadMode)
 -- Subject to fusion
 --
 -- Since 1.0.0
-sourceHandle, sourceHandleC :: (MonadIO m, IOData a) => Handle -> Producer m a
+sourceHandle, sourceHandleC :: (MonadIO m, IOData a, MonoFoldable a) => Handle -> Producer m a
 sourceHandleC h =
     loop
   where
@@ -437,7 +443,7 @@ STREAMING(sourceHandle, sourceHandleC, sourceHandleS, h)
 -- Automatically closes the file at completion.
 --
 -- Since 1.0.0
-sourceIOHandle :: (MonadResource m, IOData a) => SIO.IO Handle -> Producer m a
+sourceIOHandle :: (MonadResource m, IOData a, MonoFoldable a) => SIO.IO Handle -> Producer m a
 sourceIOHandle alloc = bracketP alloc SIO.hClose sourceHandle
 {-# INLINE sourceIOHandle #-}
 
@@ -446,7 +452,7 @@ sourceIOHandle alloc = bracketP alloc SIO.hClose sourceHandle
 -- Subject to fusion
 --
 -- Since 1.0.0
-stdin :: (MonadIO m, IOData a) => Producer m a
+stdin :: (MonadIO m, IOData a, MonoFoldable a) => Producer m a
 INLINE_RULE0(stdin, sourceHandle SIO.stdin)
 
 -- | Create an infinite stream of random values, seeding from the system random
@@ -849,7 +855,11 @@ INLINE_RULE(elem, x, any (== x))
 -- Subject to fusion
 --
 -- Since 1.0.0
+#if MIN_VERSION_mono_traversable(1,0,0)
+elemE :: (Monad m, Seq.IsSequence seq, Eq (Element seq))
+#else
 elemE :: (Monad m, Seq.EqSequence seq)
+#endif
       => Element seq
       -> Consumer seq m Bool
 #if MIN_VERSION_mono_traversable(0,8,0)
@@ -875,7 +885,11 @@ INLINE_RULE(notElem, x, all (/= x))
 -- Subject to fusion
 --
 -- Since 1.0.0
+#if MIN_VERSION_mono_traversable(1,0,0)
+notElemE :: (Monad m, Seq.IsSequence seq, Eq (Element seq))
+#else
 notElemE :: (Monad m, Seq.EqSequence seq)
+#endif
          => Element seq
          -> Consumer seq m Bool
 #if MIN_VERSION_mono_traversable(0,8,0)
@@ -1124,7 +1138,11 @@ INLINE_RULE0(maximum, foldl1 max)
 -- Subject to fusion
 --
 -- Since 1.0.0
+#if MIN_VERSION_mono_traversable(1,0,0)
+maximumE :: (Monad m, Seq.IsSequence seq, Ord (Element seq)) => Consumer seq m (Maybe (Element seq))
+#else
 maximumE :: (Monad m, Seq.OrdSequence seq) => Consumer seq m (Maybe (Element seq))
+#endif
 INLINE_RULE0(maximumE, foldl1E max)
 
 -- | Get the smallest value in the stream, if present.
@@ -1140,7 +1158,11 @@ INLINE_RULE0(minimum, foldl1 min)
 -- Subject to fusion
 --
 -- Since 1.0.0
+#if MIN_VERSION_mono_traversable(1,0,0)
+minimumE :: (Monad m, Seq.IsSequence seq, Ord (Element seq)) => Consumer seq m (Maybe (Element seq))
+#else
 minimumE :: (Monad m, Seq.OrdSequence seq) => Consumer seq m (Maybe (Element seq))
+#endif
 INLINE_RULE0(minimumE, foldl1E min)
 
 -- | True if there are no values in the stream.
